@@ -54,7 +54,8 @@ def collect_cell_info(
     chemical_symbols=None,
     enforce_primitive_matrix_auto=False,
     phonopy_yaml_cls: type[PhonopyYaml] = PhonopyYaml,
-):
+    load_phonopy_yaml: bool = False,
+) -> dict:
     """Collect crystal structure information from input file and parameters.
 
     This function returns crystal structure information obtained from an input
@@ -102,6 +103,8 @@ def collect_cell_info(
         PhonopyYaml like class name. This is used to return its instance when
         needed. Default is None, which means PhonopyYaml class type. This can be
         Phono3pyYaml class type.
+    load_phonopy_yaml : bool
+        True means phonopy-load mode.
 
     Returns
     -------
@@ -123,12 +126,17 @@ def collect_cell_info(
 
     """
     # In some cases, interface mode falls back to phonopy_yaml mode.
-    fallback_reason = _fallback_to_phonopy_yaml(
-        supercell_matrix, interface_mode, cell_filename
-    )
+    if load_phonopy_yaml:
+        fallback_reason = "load_phonopy_yaml mode"
+    else:
+        fallback_reason = _fallback_to_phonopy_yaml(
+            supercell_matrix,
+            interface_mode,
+            cell_filename,
+        )
 
     _cell_filename = cell_filename
-    if fallback_reason:
+    if load_phonopy_yaml or fallback_reason:
         _interface_mode = "phonopy_yaml"
         if cell_filename is None or not is_file_phonopy_yaml(
             cell_filename, keyword=phonopy_yaml_cls.command_name
@@ -384,9 +392,7 @@ def _get_error_message(
     elif fallback_reason == "no supercell matrix given":
         msg_list.append("Supercell matrix (DIM or --dim) was not explicitly specified.")
 
-    msg_list.append(
-        f"By this reason, {phonopy_yaml_cls.command_name}_yaml mode was invoked."
-    )
+    msg_list.append(f"Switched on {phonopy_yaml_cls.command_name}-yaml mode.")
 
     if final_cell_filename is None:  # No phonopy*.yaml file was found.
         filenames = [f'"{name}"' for name in phonopy_yaml_cls.default_filenames]
@@ -398,7 +404,7 @@ def _get_error_message(
             tail = " or ".join(filenames[-2:])
             head = ", ".join(filenames[:-2])
             text = head + ", " + tail
-        msg_list.append(f"But {text} could not be found.")
+        msg_list.append(f"{text} could not be found.")
         return "\n".join(msg_list)
 
     phpy = optional_structure_info[1]
