@@ -34,41 +34,53 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
+
+import io
+import os
+from collections.abc import Sequence
+from typing import Optional, Union
+
 import numpy as np
 
 import phonopy.cui.load_helper as load_helper
 from phonopy.api_phonopy import Phonopy
 from phonopy.interface.calculator import get_default_physical_units
 from phonopy.interface.phonopy_yaml import PhonopyYaml
+from phonopy.structure.atoms import PhonopyAtoms
 from phonopy.structure.cells import get_primitive_matrix
+from phonopy.structure.dataset import forces_in_dataset
 
 
 def load(
-    phonopy_yaml=None,  # phonopy.yaml-like must be the first argument.
-    supercell_matrix=None,
-    primitive_matrix=None,
-    is_nac=True,
-    calculator=None,
-    unitcell=None,
-    supercell=None,
-    nac_params=None,
-    unitcell_filename=None,
-    supercell_filename=None,
-    born_filename=None,
-    force_sets_filename=None,
-    force_constants_filename=None,
-    fc_calculator=None,
-    fc_calculator_options=None,
-    factor=None,
-    frequency_scale_factor=None,
-    produce_fc=True,
-    is_symmetry=True,
-    symmetrize_fc=True,
-    is_compact_fc=True,
-    store_dense_svecs=False,
-    use_SNF_supercell=False,
-    symprec=1e-5,
-    log_level=0,
+    phonopy_yaml: Optional[
+        Union[str, bytes, os.PathLike, io.IOBase]
+    ] = None,  # phonopy.yaml-like must be the first argument.
+    supercell_matrix: Optional[Union[np.ndarray, Sequence]] = None,
+    primitive_matrix: Optional[Union[np.ndarray, Sequence]] = None,
+    is_nac: bool = True,
+    calculator: Optional[str] = None,
+    unitcell: Optional[PhonopyAtoms] = None,
+    supercell: Optional[PhonopyAtoms] = None,
+    nac_params: Optional[dict] = None,
+    unitcell_filename: Optional[str] = None,
+    supercell_filename: Optional[str] = None,
+    born_filename: Optional[str] = None,
+    force_sets_filename: Optional[str] = None,
+    force_constants_filename: Optional[str] = None,
+    fc_calculator: Optional[str] = None,
+    fc_calculator_options: Optional[str] = None,
+    factor: Optional[float] = None,
+    produce_fc: bool = True,
+    is_symmetry: bool = True,
+    symmetrize_fc: bool = True,
+    is_compact_fc: bool = True,
+    use_pypolymlp: bool = False,
+    mlp_params: Optional[dict] = None,
+    store_dense_svecs: bool = True,
+    use_SNF_supercell: bool = False,
+    symprec: float = 1e-5,
+    log_level: int = 0,
 ) -> Phonopy:
     """Create Phonopy instance from parameters and/or input files.
 
@@ -116,9 +128,10 @@ def load(
 
     Parameters
     ----------
-    phonopy_yaml : str, optional
-        Filename of "phonopy.yaml"-like file. If this is given, the data in the
-        file are parsed. Default is None.
+    phonopy_yaml : str, bytes, os.PathLike, io.IOBase, optional
+        Filename of "phonopy.yaml"-like file for str or bytes, otherwise file
+        pointer-like. If this is given, the data in the file are parsed. Default
+        is None.
     supercell_matrix : array_like, optional
         Supercell matrix multiplied to input cell basis vectors. shape=(3, ) or
         (3, 3), where the former is considered a diagonal matrix. Default is the
@@ -173,9 +186,6 @@ def load(
     factor : float, optional
         Phonon frequency unit conversion factor. Unless specified, default unit
         conversion factor for each calculator is used.
-    frequency_scale_factor : float, optional
-        Factor multiplied to calculated phonon frequency. Default is None, i.e.,
-        effectively 1.
     produce_fc : bool, optional
         Setting False, force constants are not calculated from dataset of
         displacements and forces even if the dataset exists. Default is True.
@@ -190,10 +200,15 @@ def load(
             True: (primitive, supecell, 3, 3) False: (supercell, supecell, 3, 3)
         where 'supercell' and 'primitive' indicate number of atoms in these
         cells. Default is True.
+    use_pypolymlp : bool, optional
+        Use pypolymlp for generating force constants. Default is False.
+    mlp_params : dict, optional
+        A set of parameters used by machine learning potentials.
     store_dense_svecs : bool, optional
-        Dataset of shortest vectors between atoms in primitive cell and
-        supercell is stored in the dense format when this is True. Default is
-        False.
+        Deprected. Dataset of shortest vectors between atoms in primitive
+        cell and supercell is stored in the dense format when this is True.
+        Default is True. In phonopy v3 or later version, False will not be
+        supported.
     use_SNF_supercell : bool, optional
         Supercell is built by SNF algorithm when True. Default is False. SNF
         algorithm is faster than the original one, but the order of atoms in the
@@ -255,7 +270,7 @@ def load(
         else:
             _calculator = calculator
     else:
-        msg = "Cell information could not found. " "Phonopy instance loading failed."
+        msg = "Cell information could not found. Phonopy instance loading failed."
         raise RuntimeError(msg)
 
     if log_level and _calculator is not None:
@@ -272,7 +287,6 @@ def load(
         smat,
         primitive_matrix=pmat,
         factor=_factor,
-        frequency_scale_factor=frequency_scale_factor,
         symprec=symprec,
         is_symmetry=is_symmetry,
         store_dense_svecs=store_dense_svecs,
@@ -294,19 +308,45 @@ def load(
         if ret_nac_params is not None:
             phonon.nac_params = ret_nac_params
 
-    # Displacements, forces, and force constants
-    load_helper.set_dataset_and_force_constants(
+    dataset = load_helper.select_and_load_dataset(
         phonon,
         _dataset,
-        _fc,
-        force_constants_filename=force_constants_filename,
         force_sets_filename=force_sets_filename,
-        fc_calculator=fc_calculator,
-        fc_calculator_options=fc_calculator_options,
-        produce_fc=produce_fc,
-        symmetrize_fc=symmetrize_fc,
+        log_level=log_level,
+    )
+    if dataset is not None:
+        phonon.dataset = dataset
+
+    fc = load_helper.select_and_extract_force_constants(
+        phonon,
+        fc=_fc,
+        force_constants_filename=force_constants_filename,
         is_compact_fc=is_compact_fc,
         log_level=log_level,
     )
+    if fc is not None:
+        phonon.force_constants = fc
+
+    if use_pypolymlp and dataset is not None:
+        phonon.mlp_dataset = dataset
+        phonon.dataset = None
+        load_helper.prepare_pypolymlp_and_dataset(
+            phonon,
+            mlp_params=mlp_params,
+            log_level=log_level,
+        )
+    if (
+        phonon.force_constants is None
+        and produce_fc
+        and forces_in_dataset(phonon.dataset)
+    ):
+        load_helper.produce_force_constants(
+            phonon,
+            fc_calculator=fc_calculator,
+            fc_calculator_options=fc_calculator_options,
+            symmetrize_fc=symmetrize_fc,
+            is_compact_fc=is_compact_fc,
+            log_level=log_level,
+        )
 
     return phonon
