@@ -94,10 +94,21 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
     )
     parser.add_argument(
         "--amplitude",
+        "--amin",
         dest="displacement_distance",
         type=float,
         default=None,
-        help="Distance of displacements",
+        help=(
+            "Distance of displacements and also minimum distance of displacements "
+            "in random displacements"
+        ),
+    )
+    parser.add_argument(
+        "--amax",
+        dest="displacement_distance_max",
+        type=float,
+        default=None,
+        help="Minimum distance of displacements in random displacements",
     )
     parser.add_argument(
         "--anime", nargs="+", dest="anime", default=None, help="Same as ANIME tag"
@@ -142,8 +153,7 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         type=int,
         default=None,
         help=(
-            "Number of points calculated on a band segment in "
-            "the band structure mode"
+            "Number of points calculated on a band segment in the band structure mode"
         ),
     )
     parser.add_argument(
@@ -152,7 +162,7 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         nargs="+",
         dest="band_indices",
         default=None,
-        help=("Band indices to be included to calcualte thermal " "properties"),
+        help=("Band indices to be included to calcualte thermal properties"),
     )
     if not load_phonopy_yaml:
         parser.add_argument(
@@ -171,13 +181,20 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
             default=None,
             help="Phonopy configuration file",
         )
+    parser.add_argument(
+        "--classical",
+        dest="classical",
+        action="store_true",
+        default=False,
+        help=("Compute thermodynamic properties using classical statistics."),
+    )
     parser.add_argument(
         "--cutoff-freq",
         "--cutoff-frequency",
         dest="cutoff_frequency",
         type=float,
         default=None,
-        help=("Thermal properties are not calculated below this " "cutoff frequency."),
+        help=("Thermal properties are not calculated below this cutoff frequency."),
     )
     parser.add_argument(
         "--cutoff-radius",
@@ -186,21 +203,13 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         default=None,
         help="Out of cutoff radius, force constants are set zero.",
     )
-    if not load_phonopy_yaml:
-        parser.add_argument(
-            "-d",
-            "--displacement",
-            dest="is_displacement",
-            action="store_true",
-            default=None,
-            help="Create supercells with displacements",
-        )
     parser.add_argument(
-        "--dense-svecs",
-        dest="store_dense_svecs",
+        "-d",
+        "--displacement",
+        dest="is_displacement",
         action="store_true",
         default=None,
-        help="Pair shortest vectors in supercell are stored in dense format.",
+        help="Create supercells with displacements",
     )
     if not load_phonopy_yaml:
         parser.add_argument(
@@ -240,7 +249,7 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
             action="store_false",
             default=None,
             help=(
-                "Exclude born effective charge and dielectric tensor in " "phonopy.yaml"
+                "Exclude born effective charge and dielectric tensor in phonopy.yaml"
             ),
         )
     parser.add_argument(
@@ -322,17 +331,17 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         default=None,
         help="Fits total DOS to a Debye model",
     )
-    parser.add_argument(
-        "--freq-scale",
-        dest="frequency_scale_factor",
-        type=float,
-        default=None,
-        help=(
-            "Squared scale factor multiplied as fc2 * factor^2. Therefore "
-            "frequency is changed but the contribution from NAC is not "
-            "changed."
-        ),
-    )
+    # parser.add_argument(
+    #     "--freq-scale",
+    #     dest="frequency_scale_factor",
+    #     type=float,
+    #     default=None,
+    #     help=(
+    #         "Squared scale factor multiplied as fc2 * factor^2. Therefore "
+    #         "frequency is changed but the contribution from NAC is not "
+    #         "changed."
+    #     ),
+    # )
     parser.add_argument(
         "--full-fc",
         dest="is_full_fc",
@@ -409,13 +418,6 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         default=None,
         help="hdf5 compression filter (default: gzip)",
     )
-    parser.add_argument(
-        "--hiphive",
-        dest="use_hiphive",
-        action="store_true",
-        default=None,
-        help="Use hiPhive for generating force constants",
-    )
     parser.add_argument(
         "--irreps",
         "--irreps-qpoint",
@@ -438,17 +440,6 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         default=None,
         help="Include force sets in phonopy.yaml",
     )
-    if not load_phonopy_yaml:
-        parser.add_argument(
-            "--include-born",
-            "--include-nac-params",
-            dest="include_nac_params",
-            action="store_true",
-            default=None,
-            help=(
-                "Include born effective charge and dielectric tensor in " "phonopy.yaml"
-            ),
-        )
     parser.add_argument(
         "--include-disp",
         dest="include_disp",
@@ -518,6 +509,15 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         default=None,
         help="Same behavior as MP tag",
     )
+    parser.add_argument(
+        "--mlp-params",
+        dest="mlp_params",
+        default=None,
+        help=(
+            "Parameters for machine learning potentials as comma separated "
+            "string with the style of key = values"
+        ),
+    )
     parser.add_argument(
         "--moment",
         dest="is_moment",
@@ -696,9 +696,8 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         "--rd",
         "--random-displacements",
         dest="random_displacements",
-        type=int,
         default=None,
-        help="Number of supercells with random displacements",
+        help='Number of supercells with random displacements or "auto".',
     )
     parser.add_argument(
         "--rd-temperature",
@@ -763,12 +762,20 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         "--sigma", dest="sigma", default=None, help="Smearing width for DOS"
     )
     parser.add_argument(
-        "--symfc",
-        dest="use_symfc",
-        action="store_true",
+        "--sscha",
+        dest="sscha_iterations",
+        type=int,
         default=None,
-        help="Use symfc for generating force constants",
+        help="Number of iterations in SSCHA calculation",
     )
+    if not fc_symmetry:
+        parser.add_argument(
+            "--symfc",
+            dest="use_symfc",
+            action="store_true",
+            default=None,
+            help="Use symfc for generating force constants",
+        )
     parser.add_argument(
         "--symmetry",
         dest="is_check_symmetry",
@@ -892,6 +899,13 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
     if load_phonopy_yaml:
         parser.add_argument("filename", nargs="*", help="phonopy.yaml like file")
     else:
-        parser.add_argument("filename", nargs="*", help="Phonopy configure file")
+        parser.add_argument(
+            "filename",
+            nargs="*",
+            help=(
+                "Phonopy configure file. However if the file is recognized as "
+                "phonopy.yaml like file, this file is read as phonopy.yaml like file."
+            ),
+        )
 
     return parser, deprecated
