@@ -36,13 +36,11 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional
+from collections.abc import Sequence
+from typing import Optional, Union
 
 import numpy as np
 
-if TYPE_CHECKING:
-    from phonopy import Phonopy
-
 from phonopy.structure.atoms import PhonopyAtoms
 from phonopy.structure.cells import (
     Primitive,
@@ -57,93 +55,137 @@ from phonopy.utils import similarity_transformation
 def get_fc2(
     supercell: PhonopyAtoms,
     symmetry: Symmetry,
-    dataset,
-    atom_list=None,
+    dataset: dict,
+    atom_list: Optional[Union[Sequence[int], np.ndarray]] = None,
     primitive: Optional[Primitive] = None,
-    decimals=None,
 ):
-    """Force constants are computed.
+    """Get 2nd order force constants."""
+    fd_fc_solver = FDFCSolver(
+        supercell, symmetry, dataset, atom_list=atom_list, primitive=primitive
+    )
+    return fd_fc_solver.force_constants[2]
 
-    Force constants, Phi, are calculated from sets for forces, F, and
-    atomic displacement, d:
-      Phi = -F / d
-    This is solved by matrix pseudo-inversion.
-    Crystal symmetry is included when creating F and d matrices.
 
-    Returns
-    -------
-    ndarray
-        Force constants[ i, j, a, b ]
-        i: Atom index of finitely displaced atom.
-        j: Atom index at which force on the atom is measured.
-        a, b: Cartesian direction indices = (0, 1, 2) for i and j, respectively
-        dtype=double
-        shape=(len(atom_list),n_satom,3,3),
+class FDFCSolver:
+    """Finite difference type force constants calculator.
+
+    This is phonopy's traditional force constants calculator.
 
     """
-    if atom_list is None:
-        fc_dim0 = len(supercell)
-    else:
-        fc_dim0 = len(atom_list)
 
-    force_constants = np.zeros(
-        (fc_dim0, len(supercell), 3, 3), dtype="double", order="C"
-    )
-
-    # Fill force_constants[ displaced_atoms, all_atoms_in_supercell ]
-    atom_list_done = _get_force_constants_disps(
-        force_constants, supercell, dataset, symmetry, atom_list=atom_list
-    )
-    rotations = symmetry.symmetry_operations["rotations"]
-    lattice = np.array(supercell.cell.T, dtype="double", order="C")
-    permutations = symmetry.atomic_permutations
-
-    if atom_list is None and primitive is not None:
-        # Distribute to atoms in primitive cell, then distribute to all.
-        distribute_force_constants(
-            force_constants,
-            atom_list_done,
-            lattice,
-            rotations,
-            permutations,
-            atom_list=primitive.p2s_map,
-            fc_indices_of_atom_list=primitive.p2s_map,
-        )
-        distribute_force_constants_by_translations(
-            force_constants, primitive, supercell
-        )
-    else:
-        distribute_force_constants(
-            force_constants,
-            atom_list_done,
-            lattice,
-            rotations,
-            permutations,
-            atom_list=atom_list,
+    def __init__(
+        self,
+        supercell: PhonopyAtoms,
+        symmetry: Symmetry,
+        dataset: dict,
+        atom_list: Optional[Union[Sequence[int], np.ndarray]] = None,
+        primitive: Optional[Primitive] = None,
+    ):
+        self._fc2 = self._run(
+            supercell, symmetry, dataset, atom_list=atom_list, primitive=primitive
         )
 
-    if decimals:
-        force_constants = force_constants.round(decimals=decimals)
+    @property
+    def force_constants(self) -> dict[int, np.ndarray]:
+        """Return force constants.
 
-    return force_constants
+        Returns
+        -------
+        dict[int, np.ndarray]
+            Force constants with order as key.
+
+        """
+        return {2: self._fc2}
+
+    def _run(
+        self,
+        supercell: PhonopyAtoms,
+        symmetry: Symmetry,
+        dataset,
+        atom_list: Optional[Union[Sequence[int], np.ndarray]] = None,
+        primitive: Optional[Primitive] = None,
+    ) -> np.ndarray:
+        """Force constants are computed.
+
+        Force constants, Phi, are calculated from sets for forces, F, and
+        atomic displacement, d:
+        Phi = -F / d
+        This is solved by matrix pseudo-inversion.
+        Crystal symmetry is included when creating F and d matrices.
+
+        Returns
+        -------
+        ndarray
+            Force constants[ i, j, a, b ]
+            i: Atom index of finitely displaced atom.
+            j: Atom index at which force on the atom is measured.
+            a, b: Cartesian direction indices = (0, 1, 2) for i and j, respectively
+            dtype=double
+            shape=(len(atom_list),n_satom,3,3),
+
+        """
+        if atom_list is None:
+            fc_dim0 = len(supercell)
+        else:
+            fc_dim0 = len(atom_list)
+
+        force_constants = np.zeros(
+            (fc_dim0, len(supercell), 3, 3), dtype="double", order="C"
+        )
+
+        # Fill force_constants[ displaced_atoms, all_atoms_in_supercell ]
+        atom_list_done = _get_force_constants_disps(
+            force_constants, supercell, dataset, symmetry, atom_list=atom_list
+        )
+        rotations = symmetry.symmetry_operations["rotations"]
+        lattice = np.array(supercell.cell.T, dtype="double", order="C")
+        permutations = symmetry.atomic_permutations
+
+        if atom_list is None and primitive is not None:
+            # Distribute to atoms in primitive cell, then distribute to all.
+            distribute_force_constants(
+                force_constants,
+                atom_list_done,
+                lattice,
+                rotations,
+                permutations,
+                atom_list=primitive.p2s_map,
+                fc_indices_of_atom_list=primitive.p2s_map,
+            )
+            distribute_force_constants_by_translations(force_constants, primitive)
+        else:
+            distribute_force_constants(
+                force_constants,
+                atom_list_done,
+                lattice,
+                rotations,
+                permutations,
+                atom_list=atom_list,
+            )
+
+        return force_constants
 
 
-def compact_fc_to_full_fc(phonon: "Phonopy", compact_fc, log_level=0):
+def compact_fc_to_full_fc(
+    primitive: Primitive, compact_fc: np.ndarray, log_level: int = 0
+):
     """Transform compact fc to full fc."""
     fc = np.zeros(
         (compact_fc.shape[1], compact_fc.shape[1], 3, 3), dtype="double", order="C"
     )
-    fc[phonon.primitive.p2s_map] = compact_fc
-    distribute_force_constants_by_translations(fc, phonon.primitive, phonon.supercell)
+    fc[primitive.p2s_map] = compact_fc
+    distribute_force_constants_by_translations(fc, primitive)
     if log_level:
         print("Force constants were expanded to full format.")
 
     return fc
 
 
-def full_fc_to_compact_fc(phonon: "Phonopy", full_fc, log_level=0):
+def full_fc_to_compact_fc(
+    primitive: Primitive, full_fc: np.ndarray, log_level: int = 0
+):
     """Transform full fc to compact fc."""
-    p2s_map = phonon.primitive.p2s_map
+    p2s_map = primitive.p2s_map
     fc = np.zeros((len(p2s_map), full_fc.shape[1], 3, 3), dtype="double", order="C")
     fc[:] = full_fc[p2s_map]
     if log_level:
@@ -181,7 +223,11 @@ def rearrange_force_constants_array(
 
 
 def cutoff_force_constants(
-    force_constants, supercell, primitive, cutoff_radius, symprec=1e-5
+    force_constants: np.ndarray,
+    supercell: PhonopyAtoms,
+    primitive: Primitive,
+    cutoff_radius: float,
+    symprec=1e-5,
 ):
     """Set zero to force constants outside of cutoff distance.
 
@@ -218,7 +264,7 @@ def cutoff_force_constants(
                 force_constants[i, j] = 0.0
 
 
-def symmetrize_force_constants(force_constants, level=1):
+def symmetrize_force_constants(force_constants: np.ndarray, level: int = 1):
     """Symmetry force constants by translational and permutation symmetries.
 
     Note
@@ -345,9 +391,7 @@ def distribute_force_constants(
     )
 
 
-def distribute_force_constants_by_translations(
-    fc, primitive: Primitive, supercell: PhonopyAtoms
-):
+def distribute_force_constants_by_translations(fc: np.ndarray, primitive: Primitive):
     """Distribute compact fc data to full fc by pure translations.
 
     For example, the input fc has to be prepared in the following way
@@ -360,7 +404,7 @@ def distribute_force_constants_by_translations(
     """
     p2s = primitive.p2s_map
     permutations = primitive.atomic_permutations
-    lattice = supercell.cell.T
+    lattice = primitive.cell.T @ np.linalg.inv(primitive.primitive_matrix)
     rotations = np.array(
         [np.eye(3, dtype="intc")] * permutations.shape[0], dtype="intc", order="C"
     )
@@ -383,7 +427,9 @@ def solve_force_constants(
     else:
         fc_index = np.where(disp_atom_number == atom_list)[0]
         if len(fc_index) == 0:
-            raise RuntimeError
+            raise RuntimeError(
+                "Force constants could not be sovlved by finite difference method."
+            )
         else:
             fc_index = fc_index[0]
     force_constants[fc_index] = _solve_force_constants_svd(
@@ -785,42 +831,6 @@ def _get_force_constants_disps(
     return disp_atom_list
 
 
-def _combine_force_constants_equivalent_atoms(
-    fc_combined, force_constants, i, cart_rot, map_atoms, mapa
-):
-    num_equiv_atoms = 0
-    for j, k in enumerate(map_atoms):
-        if k != i:
-            continue
-
-        num_equiv_atoms += 1
-        r_i = (mapa[:, j] == i).nonzero()[0][0]
-        for k, ll in enumerate(mapa[r_i]):
-            fc_combined[ll] += similarity_transformation(
-                cart_rot[r_i], force_constants[j, k]
-            )
-
-    fc_combined /= num_equiv_atoms
-
-    return num_equiv_atoms
-
-
-def _average_force_constants_by_sitesym(fc_new, fc_i, i, cart_rot, mapa):
-    num_sitesym = 0
-    for r_i, mapa_r in enumerate(mapa):
-        if mapa_r[i] != i:
-            continue
-        num_sitesym += 1
-        for j in range(fc_i.shape[0]):
-            fc_new[i, j] += similarity_transformation(
-                cart_rot[r_i].T, fc_i[mapa[r_i, j]]
-            )
-
-    fc_new[i] /= num_sitesym
-
-    return num_sitesym
-
-
 def _get_atom_indices_by_symmetry(lattice, positions, rotations, translations, symprec):
     # To understand this method, understanding numpy broadcasting is mandatory.
 
@@ -846,16 +856,6 @@ def _get_atom_indices_by_symmetry(lattice, positions, rotations, translations, s
     return mapa
 
 
-def _get_shortest_distance_in_PBC(pos_i, pos_j, reduced_bases):
-    distances = []
-    for k in (-1, 0, 1):
-        for ll in (-1, 0, 1):
-            for m in (-1, 0, 1):
-                diff = pos_j + np.array([k, ll, m]) - pos_i
-                distances.append(np.linalg.norm(np.dot(diff, reduced_bases)))
-    return np.min(distances)
-
-
 def _get_sym_mappings_from_permutations(permutations, atom_list_done):
     """Find atomic indices where force constants have not yet calculated.
 
