@@ -50,7 +50,7 @@ from phonopy.interface.vasp import (
     get_drift_forces,
     get_scaled_positions_lines,
 )
-from phonopy.structure.atoms import PhonopyAtoms, symbol_map
+from phonopy.structure.atoms import PhonopyAtoms, split_symbol_and_index, symbol_map
 from phonopy.structure.cells import get_primitive, get_supercell
 from phonopy.units import Bohr
 
@@ -87,8 +87,14 @@ def read_pwscf(filename):
         pwscf_in = PwscfIn(f.readlines())
     tags = pwscf_in.get_tags()
     lattice = tags["cell_parameters"]
-    positions = [pos[1] for pos in tags["atomic_positions"]]
+    if pwscf_in.cartesian_positions:
+        positions = [pos[1] for pos in tags["atomic_positions"]]
+        scaled_positions = None
+    else:
+        positions = None
+        scaled_positions = [pos[1] for pos in tags["atomic_positions"]]
     species = [pos[0] for pos in tags["atomic_positions"]]
+
     mass_map = {}
     pp_map = {}
     for vals in tags["atomic_species"]:
@@ -97,47 +103,36 @@ def read_pwscf(filename):
     masses = [mass_map[x] for x in species]
     pp_all_filenames = [pp_map[x] for x in species]
 
-    unique_species = []
-    for x in species:
-        if x not in unique_species:
-            unique_species.append(x)
-
-    numbers = []
-    is_unusual = False
-    for x in species:
-        if x in symbol_map:
-            numbers.append(symbol_map[x])
-        else:
-            numbers.append(-unique_species.index(x))
-            is_unusual = True
-
-    if is_unusual:
-        positive_numbers = []
-        for n in numbers:
-            if n > 0:
-                if n not in positive_numbers:
-                    positive_numbers.append(n)
-
-        available_numbers = list(range(1, 119))
-        for pn in positive_numbers:
-            available_numbers.remove(pn)
-
-        for i, n in enumerate(numbers):
-            if n < 1:
-                numbers[i] = available_numbers[-n]
+    use_given_masses = False
+    for symnum in species:  # symnum is like 'H', 'H1', 'H2', ...
+        symbol, num = split_symbol_and_index(symnum)
+        if symbol not in symbol_map:
+            RuntimeError(f"Element {symbol} is not supported.")
+        if num > 0:
+            use_given_masses = True
 
+    if use_given_masses:
         cell = PhonopyAtoms(
-            numbers=numbers, masses=masses, cell=lattice, scaled_positions=positions
+            symbols=species,
+            cell=lattice,
+            positions=positions,
+            scaled_positions=scaled_positions,
+            masses=masses,
         )
     else:
-        cell = PhonopyAtoms(numbers=numbers, cell=lattice, scaled_positions=positions)
+        cell = PhonopyAtoms(
+            symbols=species,
+            cell=lattice,
+            positions=positions,
+            scaled_positions=scaled_positions,
+        )
 
     unique_symbols = []
     pp_filenames = {}
-    for i, symbol in enumerate(cell.symbols):
-        if symbol not in unique_symbols:
-            unique_symbols.append(symbol)
-            pp_filenames[symbol] = pp_all_filenames[i]
+    for i, symnum in enumerate(cell.symbols):
+        if symnum not in unique_symbols:
+            unique_symbols.append(symnum)
+            pp_filenames[symnum] = pp_all_filenames[i]
 
     return cell, pp_filenames
 
@@ -222,8 +217,14 @@ class PwscfIn:
         self._tags = {}
         self._current_tag_name = None
         self._values = None
+        self._cartesian_positions = False
         self._collect(lines)
 
+    @property
+    def cartesian_positions(self):
+        """Return True if positions are in Cartesian coordinates."""
+        return self._cartesian_positions
+
     def get_tags(self):
         """Return tags."""
         return self._tags
@@ -293,6 +294,14 @@ class PwscfIn:
 
         Invoked by CELL_PARAMETERS tag_name.
 
+        self._values[0] = unit
+        self._values[1:] = [a1, a2, a3, b1, b2, b3, c1, c2, c3]
+
+        is transformed to
+
+        self._tags["cell_parameters"] =
+            unit_factor * [[a1, a2, a3], [b1, b2, b3], [c1, c2, c3]]
+
         """
         unit = self._values[0].lower()
         if unit == "alat":
@@ -314,29 +323,61 @@ class PwscfIn:
         self._tags["cell_parameters"] = lattice * factor
 
     def _set_positions(self):
+        """Set atomic positions.
+
+        self._values[0] = unit
+        self._values[1:] = [species, x, y, z, ...]
+
+        is transformed to
+
+        self._cartesian_positions is set to True if unit is "angstrom" or "bohr".
+        self._tags["atomic_positions"] = [[species, unit_factor * [x, y, z]], ...]
+
+        """
         unit = self._values[0].lower()
-        if "crystal" not in unit:
+        factor = 1.0
+        if "angstrom" in unit:
+            factor = 1.0 / Bohr
+            self._cartesian_positions = True
+        elif "bohr" in unit:
+            self._cartesian_positions = True
+        elif "crystal" not in unit:
             raise RuntimeError(
-                "Only ATOMIC_POSITIONS format with " "crystal coordinates is supported."
+                "Only supported ATOMIC_POSITIONS formats: crystal/bohr/angstrom."
             )
 
         natom = self._tags["nat"]
         pos_vals = self._values[1:]
-        if len(pos_vals) < natom * 4:
-            raise RuntimeError("ATOMIC_POSITIONS is wrongly set.")
+        if len(pos_vals) != natom * 4:
+            raise RuntimeError(
+                "ATOMIC_POSITIONS is wrongly set or incompatible with nat."
+            )
 
         positions = []
         for i in range(natom):
-            positions.append(
-                [pos_vals[i * 4], [float(x) for x in pos_vals[i * 4 + 1 : i * 4 + 4]]]
-            )
+            row = [
+                pos_vals[i * 4],
+                [factor * float(x) for x in pos_vals[i * 4 + 1 : i * 4 + 4]],
+            ]
+            positions.append(row)
 
         self._tags["atomic_positions"] = positions
 
     def _set_atom_types(self):
+        """Set atomic species.
+
+        self._values = [species, mass, pp_filename, ...]
+
+        is transformed to
+
+        self._tags["atomic_species"] = [[species, mass, pp_filename], ...]
+
+        """
         num_types = self._tags["ntyp"]
-        if len(self._values) < num_types * 3:
-            raise RuntimeError("%s is wrongly set." % self._current_tag_name)
+        if len(self._values) != num_types * 3:
+            raise RuntimeError(
+                f"{self._current_tag_name} is wrongly set or inconpatible with ntyp."
+            )
 
         species = []
 
@@ -556,7 +597,7 @@ class PH_Q2R:
             fc = np.zeros((natom_s, natom_s, 3, 3), dtype="double", order="C")
             p2s = pcell.get_primitive_to_supercell_map()
             fc[p2s, :] = q2r_fc[:, site_map]
-            distribute_force_constants_by_translations(fc, pcell, scell)
+            distribute_force_constants_by_translations(fc, pcell)
         else:
             fc = np.zeros((natom, natom_s, 3, 3), dtype="double", order="C")
             fc[:, :] = q2r_fc[:, site_map]
