@@ -39,6 +39,11 @@ import warnings
 from collections.abc import Sequence
 from typing import Optional
 
+try:
+    from spglib import SpglibDataset
+except ImportError:
+    from types import SimpleNamespace as SpglibDataset
+
 import numpy as np
 import spglib
 
@@ -48,7 +53,7 @@ from phonopy.structure.cells import (
     get_primitive,
     get_supercell,
 )
-from phonopy.utils import similarity_transformation
+from phonopy.utils import get_dot_access_dataset, similarity_transformation
 
 
 class Symmetry:
@@ -165,8 +170,7 @@ class Symmetry:
     def get_pointgroup(self):
         """Return symbol of crystallographic point group."""
         warnings.warn(
-            "Symmetry.get_pointgroup() is deprecated."
-            "Use pointgroup_symbol attribute.",
+            "Symmetry.get_pointgroup() is deprecated.Use pointgroup_symbol attribute.",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -181,7 +185,7 @@ class Symmetry:
         return self._wyckoff_letters
 
     @property
-    def dataset(self):
+    def dataset(self) -> SpglibDataset:
         """Return spglib dataset.
 
         This is raw data of symmetry.
@@ -192,7 +196,7 @@ class Symmetry:
     def get_dataset(self):
         """Return spglib dataset."""
         warnings.warn(
-            "Symmetry.get_dataset() is deprecated." "Use dataset attribute.",
+            "Symmetry.get_dataset() is deprecated.Use dataset attribute.",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -207,7 +211,7 @@ class Symmetry:
 
         Returns
         -------
-        spglib_dataset["equivalent_atoms"]
+        spglib_dataset.equivalent_atoms
         e.g.,
             [0, 0, 0, 0, 4, 4, 4, 4]
 
@@ -328,28 +332,33 @@ class Symmetry:
         return np.array(site_symmetries, dtype="intc")
 
     def _set_symmetry_dataset(self):
-        self._dataset = spglib.get_symmetry_dataset(self._cell.totuple(), self._symprec)
+        self._dataset = get_dot_access_dataset(
+            spglib.get_symmetry_dataset(self._cell.totuple(), self._symprec)
+        )
+
         self._symmetry_operations = {
-            "rotations": self._dataset["rotations"],
-            "translations": self._dataset["translations"],
+            "rotations": self._dataset.rotations,
+            "translations": self._dataset.translations,
         }
         self._international_table = "%s (%d)" % (
-            self._dataset["international"],
-            self._dataset["number"],
+            self._dataset.international,
+            self._dataset.number,
         )
-        self._wyckoff_letters = self._dataset["wyckoffs"]
+        self._wyckoff_letters = self._dataset.wyckoffs
 
-        self._map_atoms = self._dataset["equivalent_atoms"]
+        self._map_atoms = self._dataset.equivalent_atoms
 
     def _set_symmetry_operations_with_magmoms(self):
-        self._dataset = spglib.get_magnetic_symmetry_dataset(
-            self._cell.totuple(), symprec=self._symprec
+        self._dataset = get_dot_access_dataset(
+            spglib.get_magnetic_symmetry_dataset(
+                self._cell.totuple(), symprec=self._symprec
+            )
         )
         self._symmetry_operations = {
-            "rotations": self._dataset["rotations"],
-            "translations": self._dataset["translations"],
+            "rotations": self._dataset.rotations,
+            "translations": self._dataset.translations,
         }
-        self._map_atoms = self._dataset["equivalent_atoms"]
+        self._map_atoms = self._dataset.equivalent_atoms
 
     def _set_independent_atoms(self):
         indep_atoms = []
@@ -621,8 +630,7 @@ def symmetrize_borns_and_epsilon(
 
     if (abs(borns - borns_) > 0.1).any():
         lines = [
-            "Symmetry of Born effective charge is largely broken. "
-            "The difference is:",
+            "Symmetry of Born effective charge is largely broken. The difference is:",
             "%s" % (borns - borns_),
         ]
         import warnings
@@ -654,7 +662,13 @@ def symmetrize_borns_and_epsilon(
             return borns_in_prim[idx2].copy(), epsilon_
 
 
-def _take_average_of_borns(borns, rotations, translations, cell, symprec):
+def _take_average_of_borns(
+    borns: np.ndarray,
+    rotations: np.ndarray,
+    translations: np.ndarray,
+    cell: PhonopyAtoms,
+    symprec: float,
+) -> np.ndarray:
     lattice = cell.cell
     positions = cell.scaled_positions
     borns_ = np.zeros_like(borns)
