@@ -40,3 +40,22 @@ import numpy as np
 def similarity_transformation(rot, mat):
     """Similarity transformation by R x M x R^-1."""
     return np.dot(rot, np.dot(mat, np.linalg.inv(rot)))
+
+
+def get_dot_access_dataset(dataset):
+    """Return dataset with dot access.
+
+    From spglib 2.5, dataset is returned as dataclass.
+    To emulate it for older versions, this function is used.
+
+    """
+    import spglib
+
+    spg_version = tuple(int(v) for v in spglib.__version__.split(".")[:3])
+
+    if spg_version < (2, 5, 0):
+        from types import SimpleNamespace
+
+        return SimpleNamespace(**dataset)
+    else:
+        return dataset
