@@ -1,6 +1,7 @@
 """Tests of Phonopy API."""
 
 import copy
+from importlib.metadata import version
 from pathlib import Path
 
 import numpy as np
@@ -255,19 +256,36 @@ def test_mlp_NaCl_type2(ph_nacl_rd: Phonopy):
     ph.produce_force_constants(fc_calculator="symfc")
     ph.run_mesh([2, 2, 2])
     freqs = ph.get_mesh_dict()["frequencies"]
-    # print(freqs.ravel().tolist())
-    freqs_ref = [
-        1.9486198781761899,
-        1.9486198781761965,
-        3.2013391476873494,
-        4.318425526312041,
-        4.318425526312042,
-        6.962529613539249,
-        2.7418677037679853,
-        3.558305139894322,
-        3.9222690417375814,
-        4.487750019058183,
-        4.895750076392935,
-        5.461698684467867,
-    ]
+    print(freqs.ravel().tolist())
+
+    if tuple(map(int, version("pypolymlp").split(".")[:3])) > (0, 5, 0):
+        freqs_ref = [
+            1.9486462367567907,
+            1.9486462367567923,
+            3.2014549283064433,
+            4.318381305851432,
+            4.318381305851434,
+            6.962599794967712,
+            2.7417694382699254,
+            3.5582818988139544,
+            3.9221249615093376,
+            4.487588845789148,
+            4.89564547559005,
+            5.461687294255339,
+        ]
+    else:
+        freqs_ref = [
+            1.9486198781761899,
+            1.9486198781761965,
+            3.2013391476873494,
+            4.318425526312041,
+            4.318425526312042,
+            6.962529613539249,
+            2.7418677037679853,
+            3.558305139894322,
+            3.9222690417375814,
+            4.487750019058183,
+            4.895750076392935,
+            5.461698684467867,
+        ]
     np.testing.assert_allclose(freqs.ravel(), freqs_ref, atol=1e-5)
